@@ -13,9 +13,10 @@
 
 from snaptrade_client.model.account import Account
 from snaptrade_client.model.account_balance import AccountBalance
-from snaptrade_client.model.account_balance_nullable import AccountBalanceNullable
+from snaptrade_client.model.account_cash_restrictions import AccountCashRestrictions
 from snaptrade_client.model.account_holdings import AccountHoldings
 from snaptrade_client.model.account_holdings_account import AccountHoldingsAccount
+from snaptrade_client.model.account_id import AccountID
 from snaptrade_client.model.account_ids import AccountIDs
 from snaptrade_client.model.account_meta import AccountMeta
 from snaptrade_client.model.account_order_record import AccountOrderRecord
@@ -24,40 +25,35 @@ from snaptrade_client.model.account_simple import AccountSimple
 from snaptrade_client.model.account_sync_status import AccountSyncStatus
 from snaptrade_client.model.action import Action
 from snaptrade_client.model.action_strict import ActionStrict
-from snaptrade_client.model.amount import Amount
-from snaptrade_client.model.amount_nullable import AmountNullable
 from snaptrade_client.model.balance import Balance
 from snaptrade_client.model.brokerage import Brokerage
+from snaptrade_client.model.brokerage_auth_id import BrokerageAuthID
 from snaptrade_client.model.brokerage_auth_ids import BrokerageAuthIDs
 from snaptrade_client.model.brokerage_authorization import BrokerageAuthorization
+from snaptrade_client.model.brokerage_authorization_disabled_confirmation import BrokerageAuthorizationDisabledConfirmation
 from snaptrade_client.model.brokerage_authorization_meta import BrokerageAuthorizationMeta
-from snaptrade_client.model.brokerage_authorization_type import BrokerageAuthorizationType
+from snaptrade_client.model.brokerage_authorization_refresh_confirmation import BrokerageAuthorizationRefreshConfirmation
 from snaptrade_client.model.brokerage_authorization_type_read_only import BrokerageAuthorizationTypeReadOnly
 from snaptrade_client.model.brokerage_authorization_type_read_only_brokerage import BrokerageAuthorizationTypeReadOnlyBrokerage
 from snaptrade_client.model.brokerage_exchanges import BrokerageExchanges
-from snaptrade_client.model.brokerage_symbol import BrokerageSymbol
+from snaptrade_client.model.brokerage_symbol_id import BrokerageSymbolID
 from snaptrade_client.model.brokerage_type import BrokerageType
-from snaptrade_client.model.calculated_trade import CalculatedTrade
-from snaptrade_client.model.cancelled_units import CancelledUnits
 from snaptrade_client.model.cash import Cash
-from snaptrade_client.model.cash_restriction import CashRestriction
 from snaptrade_client.model.client_id import ClientID
-from snaptrade_client.model.consumer_key import ConsumerKey
 from snaptrade_client.model.currency import Currency
 from snaptrade_client.model.currency_nullable import CurrencyNullable
 from snaptrade_client.model.delete_user_response import DeleteUserResponse
 from snaptrade_client.model.dividend_at_date import DividendAtDate
-from snaptrade_client.model.email import Email
 from snaptrade_client.model.encrypted_response import EncryptedResponse
 from snaptrade_client.model.encrypted_response_encrypted_message_data import EncryptedResponseEncryptedMessageData
 from snaptrade_client.model.exchange import Exchange
+from snaptrade_client.model.exchange_id import ExchangeID
 from snaptrade_client.model.exchange_rate_pairs import ExchangeRatePairs
-from snaptrade_client.model.excluded_asset import ExcludedAsset
 from snaptrade_client.model.figi_instrument import FigiInstrument
 from snaptrade_client.model.figi_instrument_nullable import FigiInstrumentNullable
-from snaptrade_client.model.filled_units import FilledUnits
+from snaptrade_client.model.holdings_status import HoldingsStatus
+from snaptrade_client.model.holdings_sync_status_date import HoldingsSyncStatusDate
 from snaptrade_client.model.id import Id
-from snaptrade_client.model.jwt import JWT
 from snaptrade_client.model.login_redirect_uri import LoginRedirectURI
 from snaptrade_client.model.manual_trade import ManualTrade
 from snaptrade_client.model.manual_trade_and_impact import ManualTradeAndImpact
@@ -66,22 +62,18 @@ from snaptrade_client.model.manual_trade_form import ManualTradeForm
 from snaptrade_client.model.manual_trade_symbol import ManualTradeSymbol
 from snaptrade_client.model.model400_failed_request_response import Model400FailedRequestResponse
 from snaptrade_client.model.model401_failed_request_response import Model401FailedRequestResponse
+from snaptrade_client.model.model402_brokerage_auth_already_disabled_exception import Model402BrokerageAuthAlreadyDisabledException
+from snaptrade_client.model.model402_brokerage_auth_disabled_response import Model402BrokerageAuthDisabledResponse
 from snaptrade_client.model.model403_failed_request_response import Model403FailedRequestResponse
+from snaptrade_client.model.model403_feature_not_enabled_response import Model403FeatureNotEnabledResponse
 from snaptrade_client.model.model404_failed_request_response import Model404FailedRequestResponse
 from snaptrade_client.model.model500_unexpected_exception_response import Model500UnexpectedExceptionResponse
-from snaptrade_client.model.model_asset_class import ModelAssetClass
-from snaptrade_client.model.model_asset_class_details import ModelAssetClassDetails
-from snaptrade_client.model.model_asset_class_target import ModelAssetClassTarget
-from snaptrade_client.model.model_portfolio import ModelPortfolio
-from snaptrade_client.model.model_portfolio_asset_class import ModelPortfolioAssetClass
-from snaptrade_client.model.model_portfolio_details import ModelPortfolioDetails
-from snaptrade_client.model.model_portfolio_security import ModelPortfolioSecurity
 from snaptrade_client.model.monthly_dividends import MonthlyDividends
 from snaptrade_client.model.net_contributions import NetContributions
 from snaptrade_client.model.net_dividend import NetDividend
 from snaptrade_client.model.notional_value import NotionalValue
 from snaptrade_client.model.notional_value_nullable import NotionalValueNullable
-from snaptrade_client.model.open_units import OpenUnits
+from snaptrade_client.model.option_brokerage_symbol import OptionBrokerageSymbol
 from snaptrade_client.model.option_chain import OptionChain
 from snaptrade_client.model.option_chain_item import OptionChainItem
 from snaptrade_client.model.option_chain_item_chain_per_root import OptionChainItemChainPerRoot
@@ -91,7 +83,7 @@ from snaptrade_client.model.option_chain_item_chain_per_root_item_chain_per_stri
 from snaptrade_client.model.option_leg import OptionLeg
 from snaptrade_client.model.option_strategy import OptionStrategy
 from snaptrade_client.model.option_strategy_legs import OptionStrategyLegs
-from snaptrade_client.model.options_holdings import OptionsHoldings
+from snaptrade_client.model.option_symbol_id import OptionSymbolID
 from snaptrade_client.model.options_position import OptionsPosition
 from snaptrade_client.model.options_symbol import OptionsSymbol
 from snaptrade_client.model.options_symbol_nullable import OptionsSymbolNullable
@@ -99,28 +91,18 @@ from snaptrade_client.model.order_type import OrderType
 from snaptrade_client.model.order_type_strict import OrderTypeStrict
 from snaptrade_client.model.partner_data import PartnerData
 from snaptrade_client.model.past_value import PastValue
-from snaptrade_client.model.percent import Percent
 from snaptrade_client.model.performance_custom import PerformanceCustom
 from snaptrade_client.model.performance_custom_bad_tickers import PerformanceCustomBadTickers
-from snaptrade_client.model.portfolio_group import PortfolioGroup
-from snaptrade_client.model.portfolio_group_info import PortfolioGroupInfo
-from snaptrade_client.model.portfolio_group_position import PortfolioGroupPosition
-from snaptrade_client.model.portfolio_group_settings import PortfolioGroupSettings
+from snaptrade_client.model.portfolio_group_id import PortfolioGroupID
 from snaptrade_client.model.position import Position
 from snaptrade_client.model.position_symbol import PositionSymbol
 from snaptrade_client.model.price import Price
-from snaptrade_client.model.redirect_tokenand_pin import RedirectTokenandPin
 from snaptrade_client.model.reporting_date import ReportingDate
 from snaptrade_client.model.reporting_frequency import ReportingFrequency
-from snaptrade_client.model.rsa_public_key import RsaPublicKey
 from snaptrade_client.model.security_type import SecurityType
+from snaptrade_client.model.security_type_id import SecurityTypeID
 from snaptrade_client.model.session_event import SessionEvent
-from snaptrade_client.model.signature import Signature
-from snaptrade_client.model.signed_content import SignedContent
-from snaptrade_client.model.snap_trade_api_disclaimer_accept_status import SnapTradeAPIDisclaimerAcceptStatus
 from snaptrade_client.model.snap_trade_holdings_account import SnapTradeHoldingsAccount
-from snaptrade_client.model.snap_trade_holdings_account_account_id import SnapTradeHoldingsAccountAccountId
-from snaptrade_client.model.snap_trade_holdings_account_account_id_meta import SnapTradeHoldingsAccountAccountIdMeta
 from snaptrade_client.model.snap_trade_holdings_account_meta import SnapTradeHoldingsAccountMeta
 from snaptrade_client.model.snap_trade_holdings_total_value import SnapTradeHoldingsTotalValue
 from snaptrade_client.model.snap_trade_login_user_request_body import SnapTradeLoginUserRequestBody
@@ -129,35 +111,18 @@ from snaptrade_client.model.snap_trade_user_id import SnapTradeUserID
 from snaptrade_client.model.snap_trade_user_secret import SnapTradeUserSecret
 from snaptrade_client.model.status import Status
 from snaptrade_client.model.stop_price import StopPrice
-from snaptrade_client.model.strategy_impact import StrategyImpact
-from snaptrade_client.model.strategy_impact_legs import StrategyImpactLegs
-from snaptrade_client.model.strategy_impact_legs_item import StrategyImpactLegsItem
-from snaptrade_client.model.strategy_order_place import StrategyOrderPlace
-from snaptrade_client.model.strategy_order_place_orders import StrategyOrderPlaceOrders
-from snaptrade_client.model.strategy_order_place_orders_item import StrategyOrderPlaceOrdersItem
-from snaptrade_client.model.strategy_order_place_orders_item_legs import StrategyOrderPlaceOrdersItemLegs
-from snaptrade_client.model.strategy_order_place_orders_item_legs_item import StrategyOrderPlaceOrdersItemLegsItem
-from snaptrade_client.model.strategy_order_quotes import StrategyOrderQuotes
 from snaptrade_client.model.strategy_order_record import StrategyOrderRecord
 from snaptrade_client.model.strategy_quotes import StrategyQuotes
 from snaptrade_client.model.strategy_quotes_greek import StrategyQuotesGreek
 from snaptrade_client.model.sub_period_return_rate import SubPeriodReturnRate
 from snaptrade_client.model.symbol import Symbol
+from snaptrade_client.model.symbol_nullable import SymbolNullable
 from snaptrade_client.model.symbol_query import SymbolQuery
 from snaptrade_client.model.symbols_quotes import SymbolsQuotes
 from snaptrade_client.model.sync_status_date import SyncStatusDate
-from snaptrade_client.model.target_asset import TargetAsset
-from snaptrade_client.model.target_asset_list import TargetAssetList
-from snaptrade_client.model.target_asset_meta import TargetAssetMeta
 from snaptrade_client.model.time import Time
 from snaptrade_client.model.time_in_force import TimeInForce
 from snaptrade_client.model.time_in_force_strict import TimeInForceStrict
-from snaptrade_client.model.time_nullable import TimeNullable
-from snaptrade_client.model.timestamp import Timestamp
-from snaptrade_client.model.trade import Trade
-from snaptrade_client.model.trade_execution_status import TradeExecutionStatus
-from snaptrade_client.model.trade_execution_status_meta import TradeExecutionStatusMeta
-from snaptrade_client.model.trade_impact import TradeImpact
 from snaptrade_client.model.transactions_status import TransactionsStatus
 from snaptrade_client.model.us_exchange import USExchange
 from snaptrade_client.model.underlying_symbol import UnderlyingSymbol
@@ -165,11 +130,9 @@ from snaptrade_client.model.units import Units
 from snaptrade_client.model.units_nullable import UnitsNullable
 from snaptrade_client.model.universal_activity import UniversalActivity
 from snaptrade_client.model.universal_symbol import UniversalSymbol
-from snaptrade_client.model.universal_symbol_nullable import UniversalSymbolNullable
-from snaptrade_client.model.user_error_log import UserErrorLog
+from snaptrade_client.model.universal_symbol_id import UniversalSymbolID
 from snaptrade_client.model.user_id import UserID
 from snaptrade_client.model.user_i_dand_secret import UserIDandSecret
 from snaptrade_client.model.user_list import UserList
 from snaptrade_client.model.user_secret import UserSecret
-from snaptrade_client.model.user_settings import UserSettings
 from snaptrade_client.model.validated_trade_body import ValidatedTradeBody
