@@ -11,10 +11,11 @@ class PathValues(str, enum.Enum):
     SNAP_TRADE_LOGIN = "/snapTrade/login"
     SNAP_TRADE_LIST_USERS = "/snapTrade/listUsers"
     SNAP_TRADE_DELETE_USER = "/snapTrade/deleteUser"
-    SNAP_TRADE_ENCRYPTED_JWT = "/snapTrade/encryptedJWT"
     SNAP_TRADE_RESET_USER_SECRET = "/snapTrade/resetUserSecret"
     AUTHORIZATIONS = "/authorizations"
     AUTHORIZATIONS_AUTHORIZATION_ID = "/authorizations/{authorizationId}"
+    AUTHORIZATIONS_AUTHORIZATION_ID_REFRESH = "/authorizations/{authorizationId}/refresh"
+    AUTHORIZATIONS_AUTHORIZATION_ID_DISABLE = "/authorizations/{authorizationId}/disable"
     SESSION_EVENTS = "/sessionEvents"
     ACCOUNTS = "/accounts"
     HOLDINGS = "/holdings"
